;; Generated package description from dape.el  -*- no-byte-compile: t -*-
(define-package "dape" "0.10.0" "Debug Adapter Protocol for Emacs" '((emacs "29.1") (jsonrpc "1.0.25")) :commit "a5c9d468c1e49e533f1146980fa86488bbe3a54e" :maintainer '("Daniel Pettersson" . "daniel@dpettersson.net") :url "https://github.com/svaante/dape")
